@@ -20,6 +20,6 @@ from .operations import xor_union, xor_intersection
 from .operations import max_intersection, min_intersection, max_union, min_union
 from .operations import ufunc_union, ufunc_intersection
 from . import geom
-from .geom import Circle, Polygon, realize_geom
+from .geom import Circle, Ellipse, Polygon, realize_geom
 from .utils import WIDE_MASK
 from .cat_healsparse_files import cat_healsparse_files
