@@ -1,11 +1,11 @@
 import numpy as np
-import healpy as hp
+import hpgeom as hpg
 import numbers
 
 from .healSparseCoverage import HealSparseCoverage
 from .utils import reduce_array, check_sentinel, _get_field_and_bitval, WIDE_NBIT, WIDE_MASK
 from .utils import is_integer_value, _compute_bitshift
-from .io_map import _read_map, _write_map
+from .io_map import _read_map, _write_map, _write_moc
 import warnings
 
 
@@ -41,8 +41,8 @@ class HealSparseMap(object):
         primary : `str`, optional
            Primary key for recarray, required if dtype has fields.
         sentinel : `int` or `float`, optional
-           Sentinel value.  Default is `hp.UNSEEN` for floating-point types,
-           and minimum int for int types.
+           Sentinel value.  Default is `UNSEEN` for floating-point types,
+           minimum int for int types, and False for bool types.
         nest : `bool`, optional
            If input healpix map is in nest format.  Default is True.
         metadata : `dict`-like, optional
@@ -69,7 +69,7 @@ class HealSparseMap(object):
         elif healpix_map is not None and nside_coverage is not None:
             # this is a healpix_map input
             if sentinel is None:
-                sentinel = hp.UNSEEN
+                sentinel = hpg.UNSEEN
             if is_integer_value(healpix_map[0]) and not is_integer_value(sentinel):
                 raise ValueError("The sentinel must be set to an integer value with an integer healpix_map")
             elif not is_integer_value(healpix_map[0]) and is_integer_value(sentinel):
@@ -79,7 +79,7 @@ class HealSparseMap(object):
                                                                        nside_coverage=nside_coverage,
                                                                        nest=nest,
                                                                        sentinel=sentinel)
-            nside_sparse = hp.npix2nside(healpix_map.size)
+            nside_sparse = hpg.npixel_to_nside(healpix_map.size)
         else:
             raise RuntimeError("Must specify either cov_map/sparse_map or healpix_map/nside_coverage")
 
@@ -166,7 +166,7 @@ class HealSparseMap(object):
         primary : `str`, optional
            Primary key for recarray, required if dtype has fields.
         sentinel : `int` or `float`, optional
-           Sentinel value.  Default is `hp.UNSEEN` for floating-point types,
+           Sentinel value.  Default is `UNSEEN` for floating-point types,
            and minimum int for int types.
         wide_mask_maxbits : `int`, optional
            Create a "wide bit mask" map, with this many bits.
@@ -286,7 +286,7 @@ class HealSparseMap(object):
                               metadata=metadata, cov_pixels=cov_pixels)
 
     @staticmethod
-    def convert_healpix_map(healpix_map, nside_coverage, nest=True, sentinel=hp.UNSEEN):
+    def convert_healpix_map(healpix_map, nside_coverage, nest=True, sentinel=hpg.UNSEEN):
         """
         Convert a healpix map to a healsparsemap.
 
@@ -300,7 +300,6 @@ class HealSparseMap(object):
            Is the input map in nest format?  Default is True.
         sentinel : `float`, optional
            Sentinel value for null values in the sparse_map.
-           Default is hp.UNSEEN
 
         Returns
         -------
@@ -310,15 +309,14 @@ class HealSparseMap(object):
            Sparse map of input values.
         """
         if not nest:
-            # must convert map to ring format
-            healpix_map = hp.reorder(healpix_map, r2n=True)
+            healpix_map = hpg.reorder(healpix_map, ring_to_nest=True)
 
         # Compute the coverage map...
         # Note that this is coming from a standard healpix map so the sentinel
-        # is always hp.UNSEEN
-        ipnest, = np.where(healpix_map > hp.UNSEEN)
+        # is always hpg.UNSEEN
+        ipnest, = np.where(healpix_map > hpg.UNSEEN)
 
-        nside_sparse = hp.npix2nside(healpix_map.size)
+        nside_sparse = hpg.npixel_to_nside(healpix_map.size)
         cov_map = HealSparseCoverage.make_empty(nside_coverage, nside_sparse)
 
         ipnest_cov = cov_map.cov_pixels(ipnest)
@@ -346,13 +344,15 @@ class HealSparseMap(object):
         nocompress : `bool`, optional
             If this is False, then integer maps will be compressed losslessly.
             Note that `np.int64` maps cannot be compressed in the FITS standard.
-            This option only applies if format='fits'.
+            This option only applies if format=``fits``.
         nside_io : `int`, optional
             The healpix nside to partition the output map files in parquet.
             Must be less than or equal to nside_coverage, and not greater than 16.
-            This option only applies if format='parquet'.
+            This option only applies if format=``parquet``.
         format : `str`, optional
-            File format.  Currently only 'fits' is supported.
+            File format.  May be ``fits``, ``parquet``, or ``healpix``. Note that
+            the ``healpix`` EXPLICIT format does not maintain all metadata and
+            coverage information.
 
         Raises
         ------
@@ -362,6 +362,20 @@ class HealSparseMap(object):
         _write_map(self, filename, clobber=clobber, nocompress=nocompress, format=format,
                    nside_io=nside_io)
 
+    def write_moc(self, filename, clobber=False):
+        """
+        Write the valid pixels of a HealSparseMap to a multi-order component (MOC)
+        file.  Note that values of the pixels are not persisted in MOC format.
+
+        Parameters
+        ----------
+        filename : `str`
+            Name of file to save
+        clobber : `bool`, optional
+            Clobber existing file?  Default is False.
+        """
+        _write_moc(self, filename, clobber=clobber)
+
     def _reserve_cov_pix(self, new_cov_pix):
         """
         Reserve new coverage pixels.  This routine does no checking, it should
@@ -413,10 +427,10 @@ class HealSparseMap(object):
         ValueError : Raised if positions do not resolve to unique
            positions and operation is 'replace'.
         """
-        return self.update_values_pix(hp.ang2pix(self._nside_sparse,
-                                                 ra_or_theta,
-                                                 dec_or_phi,
-                                                 lonlat=lonlat, nest=True),
+        return self.update_values_pix(hpg.angle_to_pixel(self._nside_sparse,
+                                                         ra_or_theta,
+                                                         dec_or_phi,
+                                                         lonlat=lonlat),
                                       values,
                                       operation=operation)
 
@@ -476,6 +490,10 @@ class HealSparseMap(object):
                         raise ValueError("Cannot set non-floating point map with a floating point.")
                     is_single_value = True
                     _values = np.array([values], dtype=self.dtype)
+                elif isinstance(values, (bool, np.bool_)):
+                    is_single_value = True
+                    _values = np.array([values], dtype=bool)
+
         if isinstance(values, np.ndarray) and len(values) == 1:
             is_single_value = True
 
@@ -491,7 +509,7 @@ class HealSparseMap(object):
             return
 
         if not nest:
-            _pix = hp.ring2nest(self._nside_sparse, pixels)
+            _pix = hpg.ring_to_nest(self._nside_sparse, pixels)
         else:
             _pix = pixels
 
@@ -656,8 +674,10 @@ class HealSparseMap(object):
         values : `np.ndarray`
            Array of values/validity from the map.
         """
-        return self.get_values_pix(hp.ang2pix(self._nside_sparse, ra_or_theta, dec_or_phi,
-                                              lonlat=lonlat, nest=True),
+        return self.get_values_pix(hpg.angle_to_pixel(self._nside_sparse,
+                                                      ra_or_theta,
+                                                      dec_or_phi,
+                                                      lonlat=lonlat),
                                    valid_mask=valid_mask)
 
     def get_values_pix(self, pixels, nest=True, valid_mask=False, nside=None):
@@ -688,7 +708,7 @@ class HealSparseMap(object):
             return np.array([], dtype=self.dtype)
 
         if not nest:
-            _pix = hp.ring2nest(self._nside_sparse, pixels)
+            _pix = hpg.ring_to_nest(self._nside_sparse, pixels)
         else:
             _pix = pixels
 
@@ -741,9 +761,10 @@ class HealSparseMap(object):
            Array of `np.bool_` flags on whether any of the input bits were
            set
         """
-        return self.check_bits_pix(hp.ang2pix(self._nside_sparse,
-                                              ra_or_theta, dec_or_phi,
-                                              lonlat=lonlat, nest=True),
+        return self.check_bits_pix(hpg.angle_to_pixel(self._nside_sparse,
+                                                      ra_or_theta,
+                                                      dec_or_phi,
+                                                      lonlat=lonlat),
                                    bits)
 
     def check_bits_pix(self, pixels, bits, nest=True):
@@ -941,7 +962,7 @@ class HealSparseMap(object):
         if self._is_rec_array:
             return False
 
-        return issubclass(self._sparse_map.dtype.type, np.integer)
+        return issubclass(self._sparse_map.dtype.type, (np.integer, np.bool_))
 
     @property
     def is_unsigned_map(self):
@@ -1106,11 +1127,11 @@ class HealSparseMap(object):
             dtypeOut = single_map._sparse_map.dtype
 
         # Create an empty HEALPix map, filled with UNSEEN values
-        hp_map = np.full(hp.nside2npix(nside), hp.UNSEEN, dtype=dtypeOut)
+        hp_map = np.full(hpg.nside_to_npixel(nside), hpg.UNSEEN, dtype=dtypeOut)
 
         valid_pixels = single_map.valid_pixels
         if not nest:
-            valid_pixels = hp.nest2ring(nside, valid_pixels)
+            valid_pixels = hpg.nest_to_ring(nside, valid_pixels)
         hp_map[valid_pixels] = single_map.get_values_pix(valid_pixels, nest=nest)
 
         return hp_map
@@ -1156,10 +1177,10 @@ class HealSparseMap(object):
         """
         if return_pixels:
             valid_pixels = self.valid_pixels
-            lon, lat = hp.pix2ang(self.nside_sparse, valid_pixels, lonlat=lonlat, nest=True)
+            lon, lat = hpg.pixel_to_angle(self.nside_sparse, valid_pixels, lonlat=lonlat)
             return (valid_pixels, lon, lat)
         else:
-            return hp.pix2ang(self.nside_sparse, self.valid_pixels, lonlat=lonlat, nest=True)
+            return hpg.pixel_to_angle(self.nside_sparse, self.valid_pixels, lonlat=lonlat)
 
     @property
     def n_valid(self):
@@ -1193,7 +1214,7 @@ class HealSparseMap(object):
         -------
         valid_area : `float`
         """
-        return self.n_valid*hp.nside2pixarea(self._nside_sparse, degrees=degrees)
+        return self.n_valid*hpg.nside_to_pixel_area(self._nside_sparse, degrees=degrees)
 
     def _degrade(self, nside_out, reduction='mean', weights=None):
         """
@@ -1227,7 +1248,8 @@ class HealSparseMap(object):
         weight_values = None
         if weights is not None:
             if reduction != 'wmean':
-                raise Warning('Weights only used with wmean reduction.  Ignoring weights.')
+                warnings.warn('Weights only used with wmean reduction.  Ignoring weights.',
+                              UserWarning)
             else:
                 # Check format/size of weight-map here.
                 if not isinstance(weights, HealSparseMap):
@@ -1265,7 +1287,7 @@ class HealSparseMap(object):
         # Work with RecArray (we have to change the resolution to all maps...)
         elif self._is_rec_array:
             dtype = []
-            sentinel_out = hp.UNSEEN
+            sentinel_out = hpg.UNSEEN
             # We should avoid integers
             for key, value in self._sparse_map.dtype.fields.items():
                 if issubclass(self._sparse_map[key].dtype.type, np.integer):
@@ -1290,11 +1312,11 @@ class HealSparseMap(object):
             sparse_map_out = reduce_array(aux, reduction=reduction)
             sentinel_out = self._sentinel
         else:
-            if issubclass(self._sparse_map.dtype.type, np.integer):
+            if issubclass(self._sparse_map.dtype.type, (np.integer, np.bool_)):
                 aux_dtype = np.float64
             else:
                 aux_dtype = self._sparse_map.dtype
-            sentinel_out = hp.UNSEEN
+            sentinel_out = hpg.UNSEEN
             aux = self._sparse_map.astype(aux_dtype)
             aux[self._sparse_map == self._sentinel] = np.nan
             aux = aux.reshape((npop_pix + 1, (nside_out//self.nside_coverage)**2, -1))
@@ -1482,7 +1504,7 @@ class HealSparseMap(object):
         elif isinstance(key, slice):
             # Get a slice of pixels
             start = key.start if key.start is not None else 0
-            stop = key.stop if key.stop is not None else hp.nside2npix(self._nside_sparse)
+            stop = key.stop if key.stop is not None else hpg.nside_to_npixel(self._nside_sparse)
             step = key.step if key.step is not None else 1
             return self.get_values_pix(np.arange(start, stop, step))
         elif isinstance(key, np.ndarray):
@@ -1513,7 +1535,7 @@ class HealSparseMap(object):
         elif isinstance(key, slice):
             # Set a slice of pixels
             start = key.start if key.start is not None else 0
-            stop = key.stop if key.stop is not None else hp.nside2npix(self._nside_sparse)
+            stop = key.stop if key.stop is not None else hpg.nside_to_npixel(self._nside_sparse)
             step = key.step if key.step is not None else 1
             return self.update_values_pix(np.arange(start, stop, step),
                                           value)
@@ -1639,7 +1661,7 @@ class HealSparseMap(object):
         """
         Convert sparse map to a different numpy datatype, including sentinel
         values.  If sentinel is not specified the default for the converted
-        datatype is used (`healpy.UNSEEN` for float, and -MAXINT for ints).
+        datatype is used (`UNSEEN` for float, and -MAXINT for ints).
 
         Parameters
         ----------
