@@ -1,6 +1,6 @@
 import os
 import numpy as np
-import healpy as hp
+import hpgeom as hpg
 
 from .fits_shim import HealSparseFits, _make_header, _write_filename
 from .utils import is_integer_value, _compute_bitshift, reduce_array, WIDE_MASK
@@ -54,21 +54,79 @@ def _read_map_fits(healsparse_class, filename, nside_coverage=None, pixels=None,
             raise NotImplementedError("Cannot specify a weightfile with degrade-on-read "
                                       "with a healpix map input.")
 
-        # This is a healpix format
-        # We need to determine the datatype, preserving it.
-        if hdr['OBJECT'].rstrip() == 'PARTIAL':
+        if 'ORDERING' not in hdr:
+            raise RuntimeError("Required keyword ORDERING not in header.")
+
+        if hdr['ORDERING'].rstrip() == 'NUNIQ':
+            # This is a MOC file.
             with HealSparseFits(filename) as fits:
-                row = fits.read_ext_data(1, row_range=[0, 1])
-                dtype = row[0]['SIGNAL'].dtype.type
-        else:
+                data = fits.read_ext_data(1)
+
+            order = np.round(np.log2(data['UNIQ']//4)).astype(np.int32)//2
+            index = data['UNIQ'] - 4*(4**order)
+
+            max_order = np.max(order)
+
+            healsparse_map = healsparse_class.make_empty(nside_coverage,
+                                                         2**max_order,
+                                                         dtype=bool)
+
+            # This is a very simple algorithm for unpacking the UNIQ
+            # pixels.  This can be optimized later if necessary.
+            pixel_arrays = []
+            for uniq_order, uniq_index in zip(order, index):
+                pixel_arrays.append(np.left_shift(uniq_index, 2*(max_order - uniq_order)) +
+                                    np.arange(4**(max_order - uniq_order)))
+            pixels = np.concatenate(pixel_arrays)
+            healsparse_map[np.sort(pixels)] = True
+
+        elif hdr['INDXSCHM'].rstrip() == 'EXPLICIT':
+            # This is an explicit (partial) healpix map
+            with HealSparseFits(filename) as fits:
+                data = fits.read_ext_data(1)
+
+            names = set(data.dtype.names)
+            names.remove('PIXEL')
+            if len(names) > 1:
+                raise NotImplementedError("HealSparse does not support multi-column partial maps.")
+
+            signal_column = list(names)[0]
+
+            if 'BAD_DATA' in hdr:
+                sentinel = hdr['BAD_DATA']
+            else:
+                sentinel = hpg.UNSEEN
+
+            healsparse_map = healsparse_class.make_empty(
+                nside_coverage,
+                hdr['NSIDE'],
+                data[0][signal_column].dtype.type,
+                sentinel=sentinel
+            )
+            if hdr['ORDERING'] == 'RING':
+                _pix = hpg.ring_to_nest(hdr['NSIDE'], data['PIXEL'])
+            else:
+                _pix = data['PIXEL']
+            healsparse_map[_pix] = data[signal_column]
+        elif hdr['INDXSCHM'].rstrip() == 'IMPLICIT':
+            try:
+                import healpy as hp
+            except ImportError:
+                raise RuntimeError("Cannot read full sky HEALPix maps without healpy.")
+            # This is an implicit (full) healpix map
+            # Figure out the datatype
             with HealSparseFits(filename) as fits:
                 row = fits.read_ext_data(1, row_range=[0, 1])
                 dtype = row[0][0][0].dtype.type
 
-        healpix_map = hp.read_map(filename, nest=True, dtype=dtype)
-        healsparse_map = healsparse_class(healpix_map=healpix_map,
-                                          nside_coverage=nside_coverage,
-                                          nest=True)
+            # Read in the map using healpy
+            healpix_map = hp.read_map(filename, nest=True, dtype=dtype)
+            # Convert to healsparse format
+            healsparse_map = healsparse_class(healpix_map=healpix_map,
+                                              nside_coverage=nside_coverage,
+                                              nest=True)
+        else:
+            raise ValueError(f"Illegal value for INDXSCHM: {hdr['INDXSCHM']}")
 
         if degrade_nside is not None:
             # Degrade this map.  Note that this could not be done on read
@@ -128,7 +186,7 @@ def _read_healsparse_fits_file(filename, pixels=None):
     primary : `str`
         Primary key field for recarray map.  Default is None.
     sentinel : `float` or `int`
-        Sentinel value for null.  Usually hp.UNSEEN
+        Sentinel value for null.  Usually UNSEEN
     """
     cov_map = HealSparseCoverage.read(filename)
     primary = None
@@ -145,7 +203,7 @@ def _read_healsparse_fits_file(filename, pixels=None):
         if 'SENTINEL' in s_hdr:
             sentinel = s_hdr['SENTINEL']
         else:
-            sentinel = hp.UNSEEN
+            sentinel = hpg.UNSEEN
     else:
         _pixels = np.atleast_1d(pixels)
         if len(np.unique(_pixels)) < len(_pixels):
@@ -169,7 +227,7 @@ def _read_healsparse_fits_file(filename, pixels=None):
             if 'SENTINEL' in s_hdr:
                 sentinel = s_hdr['SENTINEL']
             else:
-                sentinel = hp.UNSEEN
+                sentinel = hpg.UNSEEN
 
             if not fits.ext_is_image('SPARSE'):
                 # This is a table extension
@@ -181,7 +239,7 @@ def _read_healsparse_fits_file(filename, pixels=None):
                 wmult = 1
 
             # This is the map without the offset
-            cov_index_map_temp = cov_map[:] + np.arange(hp.nside2npix(nside_coverage),
+            cov_index_map_temp = cov_map[:] + np.arange(hpg.nside_to_npixel(nside_coverage),
                                                         dtype=np.int64)*cov_map.nfine_per_cov
 
             # It is not 100% sure this is the most efficient way to read in,
@@ -206,6 +264,10 @@ def _read_healsparse_fits_file(filename, pixels=None):
                                                           nside_sparse,
                                                           _pixels)
 
+    if isinstance(sentinel, bool):
+        # Convert back to boolean
+        sparse_map = sparse_map.astype(bool)
+
     return cov_map, sparse_map, nside_sparse, primary, sentinel
 
 
@@ -271,7 +333,7 @@ def _read_healsparse_fits_file_and_degrade(filename, pixels, nside_out, reductio
                                                       nside_out,
                                                       _pixels)
     # This is the map without the offset
-    cov_index_out_temp = cov_map_out[:] + np.arange(hp.nside2npix(nside_coverage),
+    cov_index_out_temp = cov_map_out[:] + np.arange(hpg.nside_to_npixel(nside_coverage),
                                                     dtype=np.int64)*cov_map_out.nfine_per_cov
     with HealSparseFits(filename) as fits:
         s_hdr = fits.read_ext_header('SPARSE')
@@ -285,7 +347,7 @@ def _read_healsparse_fits_file_and_degrade(filename, pixels, nside_out, reductio
         if 'SENTINEL' in s_hdr:
             sentinel = s_hdr['SENTINEL']
         else:
-            sentinel = hp.UNSEEN
+            sentinel = hpg.UNSEEN
 
         if not fits.ext_is_image('SPARSE'):
             # This is a table extension
@@ -312,7 +374,7 @@ def _read_healsparse_fits_file_and_degrade(filename, pixels, nside_out, reductio
             if 'SENTINEL' in s_hdr_weight:
                 sentinel_weight = s_hdr_weight['SENTINEL']
             else:
-                sentinel_weight = hp.UNSEEN
+                sentinel_weight = hpg.UNSEEN
             if ((s_hdr_weight['NSIDE'] != nside_sparse or
                  not fits.ext_is_image('SPARSE') or
                  'WIDEMASK' in s_hdr_weight or
@@ -336,7 +398,7 @@ def _read_healsparse_fits_file_and_degrade(filename, pixels, nside_out, reductio
                                       dtype=dtype_out)
         elif is_rec_array:
             dtype_out = []
-            sentinel_out = hp.UNSEEN
+            sentinel_out = hpg.UNSEEN
             # We should avoid integers
             test_arr = np.zeros(1, dtype=dtype)
             for key, value in dtype.fields.items():
@@ -359,17 +421,17 @@ def _read_healsparse_fits_file_and_degrade(filename, pixels, nside_out, reductio
                 dtype_out = np.dtype(np.float64)
             else:
                 dtype_out = dtype
-            sentinel_out = hp.UNSEEN
+            sentinel_out = hpg.UNSEEN
             sparse_map_out = np.full((_pixels.size + 1)*nfine_per_cov_out,
                                      sentinel_out,
                                      dtype=dtype_out)
 
         # This is the map without the offset
-        cov_index_map_temp = cov_map[:] + np.arange(hp.nside2npix(nside_coverage),
+        cov_index_map_temp = cov_map[:] + np.arange(hpg.nside_to_npixel(nside_coverage),
                                                     dtype=np.int64)*cov_map.nfine_per_cov
         if use_weightfile:
             cov_index_map_temp_weight = (cov_map_weight[:] +
-                                         np.arange(hp.nside2npix(nside_coverage),
+                                         np.arange(hpg.nside_to_npixel(nside_coverage),
                                                    dtype=np.int64)*cov_map.nfine_per_cov)
 
         for i, pix in enumerate(_pixels):
@@ -463,6 +525,12 @@ def _write_map_fits(hsp_map, filename, clobber=False, nocompress=False):
         _write_filename(filename, c_hdr, s_hdr, hsp_map._cov_map[:], hsp_map._sparse_map.ravel(),
                         compress=not nocompress,
                         compress_tilesize=hsp_map._wide_mask_width*hsp_map._cov_map.nfine_per_cov)
+    elif hsp_map._sparse_map[0].dtype == np.bool_:
+        # We must convert boolean maps to int16 maps for fits storage.
+        _write_filename(filename, c_hdr, s_hdr, hsp_map._cov_map[:], hsp_map._sparse_map.astype(np.int16),
+                        compress=not nocompress,
+                        compress_tilesize=hsp_map._cov_map.nfine_per_cov)
+
     elif ((hsp_map.is_integer_map and hsp_map._sparse_map[0].dtype.itemsize < 8) or
           (not hsp_map.is_integer_map and not hsp_map._is_rec_array)):
         # Integer maps < 64 bit (8 byte) can be compressed, as can
@@ -473,3 +541,62 @@ def _write_map_fits(hsp_map, filename, clobber=False, nocompress=False):
     else:
         # All other maps are not compressed.
         _write_filename(filename, c_hdr, s_hdr, hsp_map._cov_map[:], hsp_map._sparse_map)
+
+
+def _write_moc_fits(hsp_map, filename, clobber=False):
+    """
+    Write the valid pixels of a HealSparseMap to a multi-order component (MOC)
+    file.  Note that values of the pixels are not persisted in MOC format.
+
+    Parameters
+    ----------
+    hsp_map : `healsparse.HealSparseMap`
+        HealSparseMap with valid_pixels to output.
+    filename : `str`
+        Name of file to save
+    clobber : `bool`, optional
+        Clobber existing file?  Default is False.
+    """
+    import astropy.io.fits as fits
+
+    max_order = int(np.round(np.log2(hsp_map.nside_sparse)))
+    min_uniq_order = int(np.round(np.log2(hsp_map.nside_coverage)))
+
+    pixels = hsp_map.valid_pixels
+
+    uniq = 4*(4**max_order) + pixels
+
+    uniq_map = hsp_map.make_empty(hsp_map.nside_coverage, hsp_map.nside_sparse, dtype=np.float32)
+    uniq_map[pixels] = 1.0
+
+    # Loop over orders, degrade each time, and look for pixels with full coverage.
+    for uniq_order in range(max_order - 1, min_uniq_order - 1, -1):
+        uniq_map = uniq_map.degrade(2**uniq_order, reduction='sum')
+        pix_shift = np.right_shift(pixels, 2*(max_order - uniq_order))
+        # Check if any of the pixels at uniq_order have full coverage.
+        covered, = np.isclose(uniq_map[pix_shift], 4**(max_order - uniq_order)).nonzero()
+        if covered.size == 0:
+            # No pixels at uniq_order are fully covered, we're done.
+            break
+        # Replace the UNIQ pixels that are fully covered
+        uniq[covered] = 4*(4**uniq_order) + pix_shift[covered]
+
+    # Remove duplicate pixels
+    uniq = np.unique(uniq)
+
+    # Output to fits
+    tbl = np.zeros(uniq.size, dtype=[('UNIQ', 'i8')])
+    tbl['UNIQ'][:] = uniq
+
+    order = np.log2(tbl['UNIQ']//4).astype(np.int32)//2
+    moc_order = np.max(order)
+
+    hdu = fits.BinTableHDU(tbl)
+    hdu.header['PIXTYPE'] = 'HEALPIX'
+    hdu.header['ORDERING'] = 'NUNIQ'
+    hdu.header['COORDSYS'] = 'C'
+    hdu.header['MOCORDER'] = moc_order
+    hdu.header['MOCTOOL'] = 'healsparse'
+    hdu.header['MOCVERS'] = '1.1'
+
+    hdu.writeto(filename, overwrite=clobber)
