@@ -1,9 +1,7 @@
-from __future__ import division, absolute_import, print_function
-
 import unittest
 import numpy.testing as testing
 import numpy as np
-import healpy as hp
+import hpgeom as hpg
 from numpy import random
 
 import healsparse
@@ -14,7 +12,6 @@ class OperationsTestCase(unittest.TestCase):
         """
         Test map addition.
         """
-
         random.seed(seed=12345)
 
         nside_coverage = 32
@@ -46,8 +43,8 @@ class OperationsTestCase(unittest.TestCase):
         # sum 2
         added_map_intersection = healsparse.sum_intersection([sparse_map1, sparse_map2])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-        hpmap_sum_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+        hpmap_sum_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_sum_intersection[gd] = hpmap1[gd] + hpmap2[gd]
 
         testing.assert_almost_equal(hpmap_sum_intersection, added_map_intersection.generate_healpix_map())
@@ -55,8 +52,8 @@ class OperationsTestCase(unittest.TestCase):
         # sum 3
         added_map_intersection = healsparse.sum_intersection([sparse_map1, sparse_map2, sparse_map3])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-        hpmap_sum_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+        hpmap_sum_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_sum_intersection[gd] = hpmap1[gd] + hpmap2[gd] + hpmap3[gd]
 
         testing.assert_almost_equal(hpmap_sum_intersection, added_map_intersection.generate_healpix_map())
@@ -66,8 +63,8 @@ class OperationsTestCase(unittest.TestCase):
         # sum 2
         added_map_union = healsparse.sum_union([sparse_map1, sparse_map2])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN))
-        hpmap_sum_union = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN))
+        hpmap_sum_union = np.zeros_like(hpmap1) + hpg.UNSEEN
         # This hack works because we don't have summands going below zero...
         hpmap_sum_union[gd] = np.clip(hpmap1[gd], 0.0, None) + np.clip(hpmap2[gd], 0.0, None)
 
@@ -76,8 +73,8 @@ class OperationsTestCase(unittest.TestCase):
         # sum 3
         added_map_union = healsparse.sum_union([sparse_map1, sparse_map2, sparse_map3])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN) | (hpmap3 > hp.UNSEEN))
-        hpmap_sum_union = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN) | (hpmap3 > hpg.UNSEEN))
+        hpmap_sum_union = np.zeros_like(hpmap1) + hpg.UNSEEN
         # This hack works because we don't have summands going below zero...
         hpmap_sum_union[gd] = (np.clip(hpmap1[gd], 0.0, None) +
                                np.clip(hpmap2[gd], 0.0, None) +
@@ -89,8 +86,8 @@ class OperationsTestCase(unittest.TestCase):
 
         added_map = sparse_map1 + 2
 
-        hpmapAdd2 = np.zeros_like(hpmap1) + hp.UNSEEN
-        gd, = np.where(hpmap1 > hp.UNSEEN)
+        hpmapAdd2 = np.zeros_like(hpmap1) + hpg.UNSEEN
+        gd, = np.where(hpmap1 > hpg.UNSEEN)
         hpmapAdd2[gd] = hpmap1[gd] + 2
 
         testing.assert_almost_equal(hpmapAdd2, added_map.generate_healpix_map())
@@ -99,8 +96,8 @@ class OperationsTestCase(unittest.TestCase):
 
         added_map = sparse_map1 + 2.0
 
-        hpmapAdd2 = np.zeros_like(hpmap1) + hp.UNSEEN
-        gd, = np.where(hpmap1 > hp.UNSEEN)
+        hpmapAdd2 = np.zeros_like(hpmap1) + hpg.UNSEEN
+        gd, = np.where(hpmap1 > hpg.UNSEEN)
         hpmapAdd2[gd] = hpmap1[gd] + 2.0
 
         testing.assert_almost_equal(hpmapAdd2, added_map.generate_healpix_map())
@@ -147,8 +144,8 @@ class OperationsTestCase(unittest.TestCase):
         # product of 2
         product_map_intersection = healsparse.product_intersection([sparse_map1, sparse_map2])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-        hpmap_product_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+        hpmap_product_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_product_intersection[gd] = hpmap1[gd] * hpmap2[gd]
 
         testing.assert_almost_equal(hpmap_product_intersection,
@@ -157,8 +154,8 @@ class OperationsTestCase(unittest.TestCase):
         # product of 3
         product_map_intersection = healsparse.product_intersection([sparse_map1, sparse_map2, sparse_map3])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-        hpmap_product_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+        hpmap_product_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_product_intersection[gd] = hpmap1[gd] * hpmap2[gd] * hpmap3[gd]
 
         testing.assert_almost_equal(hpmap_product_intersection,
@@ -169,13 +166,13 @@ class OperationsTestCase(unittest.TestCase):
         # product of 2
         product_map_union = healsparse.product_union([sparse_map1, sparse_map2])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN))
-        hpmap_product_union = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN))
+        hpmap_product_union = np.zeros_like(hpmap1) + hpg.UNSEEN
 
         hpmap_product_union[gd] = 1.0
-        gd1, = np.where(hpmap1[gd] > hp.UNSEEN)
+        gd1, = np.where(hpmap1[gd] > hpg.UNSEEN)
         hpmap_product_union[gd[gd1]] *= hpmap1[gd[gd1]]
-        gd2, = np.where(hpmap2[gd] > hp.UNSEEN)
+        gd2, = np.where(hpmap2[gd] > hpg.UNSEEN)
         hpmap_product_union[gd[gd2]] *= hpmap2[gd[gd2]]
 
         testing.assert_almost_equal(hpmap_product_union, product_map_union.generate_healpix_map())
@@ -183,15 +180,15 @@ class OperationsTestCase(unittest.TestCase):
         # product 3
         product_map_union = healsparse.product_union([sparse_map1, sparse_map2, sparse_map3])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN) | (hpmap3 > hp.UNSEEN))
-        hpmap_product_union = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN) | (hpmap3 > hpg.UNSEEN))
+        hpmap_product_union = np.zeros_like(hpmap1) + hpg.UNSEEN
 
         hpmap_product_union[gd] = 1.0
-        gd1, = np.where(hpmap1[gd] > hp.UNSEEN)
+        gd1, = np.where(hpmap1[gd] > hpg.UNSEEN)
         hpmap_product_union[gd[gd1]] *= hpmap1[gd[gd1]]
-        gd2, = np.where(hpmap2[gd] > hp.UNSEEN)
+        gd2, = np.where(hpmap2[gd] > hpg.UNSEEN)
         hpmap_product_union[gd[gd2]] *= hpmap2[gd[gd2]]
-        gd3, = np.where(hpmap3[gd] > hp.UNSEEN)
+        gd3, = np.where(hpmap3[gd] > hpg.UNSEEN)
         hpmap_product_union[gd[gd3]] *= hpmap3[gd[gd3]]
 
         testing.assert_almost_equal(hpmap_product_union, product_map_union.generate_healpix_map())
@@ -200,8 +197,8 @@ class OperationsTestCase(unittest.TestCase):
 
         mult_map = sparse_map1 * 2
 
-        hpmap_product2 = np.zeros_like(hpmap1) + hp.UNSEEN
-        gd, = np.where(hpmap1 > hp.UNSEEN)
+        hpmap_product2 = np.zeros_like(hpmap1) + hpg.UNSEEN
+        gd, = np.where(hpmap1 > hpg.UNSEEN)
         hpmap_product2[gd] = hpmap1[gd] * 2
 
         testing.assert_almost_equal(hpmap_product2, mult_map.generate_healpix_map())
@@ -210,8 +207,8 @@ class OperationsTestCase(unittest.TestCase):
 
         mult_map = sparse_map1 * 2.0
 
-        hpmap_product2 = np.zeros_like(hpmap1) + hp.UNSEEN
-        gd, = np.where(hpmap1 > hp.UNSEEN)
+        hpmap_product2 = np.zeros_like(hpmap1) + hpg.UNSEEN
+        gd, = np.where(hpmap1 > hpg.UNSEEN)
         hpmap_product2[gd] = hpmap1[gd] * 2.0
 
         testing.assert_almost_equal(hpmap_product2, mult_map.generate_healpix_map())
@@ -247,7 +244,7 @@ class OperationsTestCase(unittest.TestCase):
         values1 = random.randint(low=1, high=maxval, size=pixel1.size)
         sparse_map1.update_values_pix(pixel1, values1)
 
-        hpmap1 = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        hpmap1 = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = sparse_map1.valid_pixels
         hpmap1[vpix] = sparse_map1.get_values_pix(vpix)
 
@@ -261,7 +258,7 @@ class OperationsTestCase(unittest.TestCase):
         values2 = random.randint(low=1, high=maxval, size=pixel2.size)
         sparse_map2.update_values_pix(pixel2, values2)
 
-        hpmap2 = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        hpmap2 = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = sparse_map2.valid_pixels
         hpmap2[vpix] = sparse_map2.get_values_pix(vpix)
 
@@ -275,7 +272,7 @@ class OperationsTestCase(unittest.TestCase):
         values3 = random.randint(low=1, high=maxval, size=pixel3.size)
         sparse_map3.update_values_pix(pixel3, values3)
 
-        hpmap3 = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        hpmap3 = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = sparse_map3.valid_pixels
         hpmap3[vpix] = sparse_map3.get_values_pix(vpix)
 
@@ -288,7 +285,7 @@ class OperationsTestCase(unittest.TestCase):
         hpmap_product_intersection = np.zeros_like(hpmap1)
         hpmap_product_intersection[gd] = hpmap1[gd] * hpmap2[gd]
 
-        pmap = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        pmap = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = product_map_intersection.valid_pixels
         pmap[vpix] = product_map_intersection.get_values_pix(vpix)
 
@@ -301,7 +298,7 @@ class OperationsTestCase(unittest.TestCase):
         hpmap_product_intersection = np.zeros_like(hpmap1)
         hpmap_product_intersection[gd] = hpmap1[gd] * hpmap2[gd] * hpmap3[gd]
 
-        pmap = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        pmap = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = product_map_intersection.valid_pixels
         pmap[vpix] = product_map_intersection.get_values_pix(vpix)
 
@@ -321,7 +318,7 @@ class OperationsTestCase(unittest.TestCase):
         gd2, = np.where(hpmap2[gd] > sentinel)
         hpmap_product_union[gd[gd2]] *= hpmap2[gd[gd2]]
 
-        pmap = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        pmap = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = product_map_union.valid_pixels
         pmap[vpix] = product_map_union.get_values_pix(vpix)
 
@@ -341,7 +338,7 @@ class OperationsTestCase(unittest.TestCase):
         gd3, = np.where(hpmap3[gd] > sentinel)
         hpmap_product_union[gd[gd3]] *= hpmap3[gd[gd3]]
 
-        pmap = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        pmap = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = product_map_union.valid_pixels
         pmap[vpix] = product_map_union.get_values_pix(vpix)
 
@@ -355,7 +352,7 @@ class OperationsTestCase(unittest.TestCase):
         gd, = np.where(hpmap1 > sentinel)
         hpmap_product2[gd] = hpmap1[gd] * 2
 
-        pmap = np.zeros(hp.nside2npix(nside_map), dtype=np.int64)
+        pmap = np.zeros(hpg.nside_to_npixel(nside_map), dtype=np.int64)
         vpix = mult_map.valid_pixels
         pmap[vpix] = mult_map.get_values_pix(vpix)
 
@@ -397,8 +394,8 @@ class OperationsTestCase(unittest.TestCase):
             # or 2
             or_map_intersection = healsparse.or_intersection([sparse_map1, sparse_map2])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-            hpmap_or_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+            hpmap_or_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_or_intersection[gd] = hpmap1[gd].astype(dtype) | hpmap2[gd].astype(dtype)
 
             testing.assert_almost_equal(hpmap_or_intersection, or_map_intersection.generate_healpix_map())
@@ -406,8 +403,8 @@ class OperationsTestCase(unittest.TestCase):
             # or 3
             or_map_intersection = healsparse.or_intersection([sparse_map1, sparse_map2, sparse_map3])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-            hpmap_or_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+            hpmap_or_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_or_intersection[gd] = (hpmap1[gd].astype(dtype) |
                                          hpmap2[gd].astype(dtype) |
                                          hpmap3[gd].astype(dtype))
@@ -419,8 +416,8 @@ class OperationsTestCase(unittest.TestCase):
             # or 2
             or_map_union = healsparse.or_union([sparse_map1, sparse_map2])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN))
-            hpmap_or_union = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN))
+            hpmap_or_union = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_or_union[gd] = (np.clip(hpmap1[gd], 0.0, None).astype(dtype) |
                                   np.clip(hpmap2[gd], 0.0, None).astype(dtype))
 
@@ -429,8 +426,8 @@ class OperationsTestCase(unittest.TestCase):
             # or 3
             or_map_union = healsparse.or_union([sparse_map1, sparse_map2, sparse_map3])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN) | (hpmap3 > hp.UNSEEN))
-            hpmap_or_union = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN) | (hpmap3 > hpg.UNSEEN))
+            hpmap_or_union = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_or_union[gd] = (np.clip(hpmap1[gd], 0.0, None).astype(dtype) |
                                   np.clip(hpmap2[gd], 0.0, None).astype(dtype) |
                                   np.clip(hpmap3[gd], 0.0, None).astype(dtype))
@@ -441,8 +438,8 @@ class OperationsTestCase(unittest.TestCase):
 
             or_map = sparse_map1 | 2
 
-            hpmap_or2 = np.zeros_like(hpmap1) + hp.UNSEEN
-            gd, = np.where(hpmap1 > hp.UNSEEN)
+            hpmap_or2 = np.zeros_like(hpmap1) + hpg.UNSEEN
+            gd, = np.where(hpmap1 > hpg.UNSEEN)
             hpmap_or2[gd] = hpmap1[gd].astype(dtype) | 2
             testing.assert_almost_equal(hpmap_or2, or_map.generate_healpix_map())
 
@@ -488,28 +485,28 @@ class OperationsTestCase(unittest.TestCase):
             # and 2
             and_map_intersection = healsparse.and_intersection([sparse_map1, sparse_map2])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-            hpmap_and_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+            hpmap_and_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_and_intersection[gd] = hpmap1[gd].astype(dtype) & hpmap2[gd].astype(dtype)
             if dtype == np.uint64:
                 # For uint, we cannot tell the difference between 0 and UNSEEN
                 bd, = np.where(hpmap_and_intersection == 0)
-                hpmap_and_intersection[bd] = hp.UNSEEN
+                hpmap_and_intersection[bd] = hpg.UNSEEN
 
             testing.assert_almost_equal(hpmap_and_intersection, and_map_intersection.generate_healpix_map())
 
             # and 3
             and_map_intersection = healsparse.and_intersection([sparse_map1, sparse_map2, sparse_map3])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-            hpmap_and_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+            hpmap_and_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_and_intersection[gd] = (hpmap1[gd].astype(dtype) &
                                           hpmap2[gd].astype(dtype) &
                                           hpmap3[gd].astype(dtype))
             if dtype == np.uint64:
                 # For uint, we cannot tell the difference between 0 and UNSEEN
                 bd, = np.where(hpmap_and_intersection == 0)
-                hpmap_and_intersection[bd] = hp.UNSEEN
+                hpmap_and_intersection[bd] = hpg.UNSEEN
 
             testing.assert_almost_equal(hpmap_and_intersection, and_map_intersection.generate_healpix_map())
 
@@ -518,43 +515,43 @@ class OperationsTestCase(unittest.TestCase):
             # and 2
             and_map_union = healsparse.and_union([sparse_map1, sparse_map2])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN))
-            hpmap_and_union = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN))
+            hpmap_and_union = np.zeros_like(hpmap1) + hpg.UNSEEN
 
             hpmap_and_union[gd] = -1.0
-            gd1, = np.where(hpmap1[gd] > hp.UNSEEN)
+            gd1, = np.where(hpmap1[gd] > hpg.UNSEEN)
             hpmap_and_union[gd[gd1]] = (hpmap_and_union[gd[gd1]].astype(np.int64) &
                                         hpmap1[gd[gd1]].astype(np.int64))
-            gd2, = np.where(hpmap2[gd] > hp.UNSEEN)
+            gd2, = np.where(hpmap2[gd] > hpg.UNSEEN)
             hpmap_and_union[gd[gd2]] = (hpmap_and_union[gd[gd2]].astype(np.int64) &
                                         hpmap2[gd[gd2]].astype(np.int64))
             if dtype == np.uint64:
                 # For uint, we cannot tell the difference between 0 and UNSEEN
                 bd, = np.where(hpmap_and_union == 0)
-                hpmap_and_union[bd] = hp.UNSEEN
+                hpmap_and_union[bd] = hpg.UNSEEN
 
             testing.assert_almost_equal(hpmap_and_union, and_map_union.generate_healpix_map())
 
             # and 3
             and_map_union = healsparse.and_union([sparse_map1, sparse_map2, sparse_map3])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN) | (hpmap3 > hp.UNSEEN))
-            hpmap_and_union = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN) | (hpmap3 > hpg.UNSEEN))
+            hpmap_and_union = np.zeros_like(hpmap1) + hpg.UNSEEN
 
             hpmap_and_union[gd] = -1.0
-            gd1, = np.where(hpmap1[gd] > hp.UNSEEN)
+            gd1, = np.where(hpmap1[gd] > hpg.UNSEEN)
             hpmap_and_union[gd[gd1]] = (hpmap_and_union[gd[gd1]].astype(np.int64) &
                                         hpmap1[gd[gd1]].astype(np.int64))
-            gd2, = np.where(hpmap2[gd] > hp.UNSEEN)
+            gd2, = np.where(hpmap2[gd] > hpg.UNSEEN)
             hpmap_and_union[gd[gd2]] = (hpmap_and_union[gd[gd2]].astype(np.int64) &
                                         hpmap2[gd[gd2]].astype(np.int64))
-            gd3, = np.where(hpmap3[gd] > hp.UNSEEN)
+            gd3, = np.where(hpmap3[gd] > hpg.UNSEEN)
             hpmap_and_union[gd[gd3]] = (hpmap_and_union[gd[gd3]].astype(np.int64) &
                                         hpmap3[gd[gd3]].astype(np.int64))
             if dtype == np.uint64:
                 # For uint, we cannot tell the difference between 0 and UNSEEN
                 bd, = np.where(hpmap_and_union == 0)
-                hpmap_and_union[bd] = hp.UNSEEN
+                hpmap_and_union[bd] = hpg.UNSEEN
 
             testing.assert_almost_equal(hpmap_and_union, and_map_union.generate_healpix_map())
 
@@ -562,13 +559,13 @@ class OperationsTestCase(unittest.TestCase):
 
             and_map = sparse_map1 & 2
 
-            hpmap_and2 = np.zeros_like(hpmap1) + hp.UNSEEN
-            gd, = np.where(hpmap1 > hp.UNSEEN)
+            hpmap_and2 = np.zeros_like(hpmap1) + hpg.UNSEEN
+            gd, = np.where(hpmap1 > hpg.UNSEEN)
             hpmap_and2[gd] = hpmap1[gd].astype(dtype) & 2
             if dtype == np.uint64:
                 # For uint, we cannot tell the difference between 0 and UNSEEN
                 bd, = np.where(hpmap_and2 == 0)
-                hpmap_and2[bd] = hp.UNSEEN
+                hpmap_and2[bd] = hpg.UNSEEN
 
             testing.assert_almost_equal(hpmap_and2, and_map.generate_healpix_map())
 
@@ -613,8 +610,8 @@ class OperationsTestCase(unittest.TestCase):
             # xor 2
             xor_map_intersection = healsparse.xor_intersection([sparse_map1, sparse_map2])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-            hpmap_xor_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+            hpmap_xor_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_xor_intersection[gd] = hpmap1[gd].astype(np.int64) ^ hpmap2[gd].astype(np.int64)
 
             testing.assert_almost_equal(hpmap_xor_intersection, xor_map_intersection.generate_healpix_map())
@@ -622,8 +619,8 @@ class OperationsTestCase(unittest.TestCase):
             # xor 3
             xor_map_intersection = healsparse.xor_intersection([sparse_map1, sparse_map2, sparse_map3])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-            hpmap_xor_intersection = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+            hpmap_xor_intersection = np.zeros_like(hpmap1) + hpg.UNSEEN
             hpmap_xor_intersection[gd] = (hpmap1[gd].astype(np.int64) ^
                                           hpmap2[gd].astype(np.int64) ^
                                           hpmap3[gd].astype(np.int64))
@@ -635,14 +632,14 @@ class OperationsTestCase(unittest.TestCase):
             # xor 2
             xor_map_union = healsparse.xor_union([sparse_map1, sparse_map2])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN))
-            hpmap_xor_union = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN))
+            hpmap_xor_union = np.zeros_like(hpmap1) + hpg.UNSEEN
 
             hpmap_xor_union[gd] = 0.0
-            gd1, = np.where(hpmap1[gd] > hp.UNSEEN)
+            gd1, = np.where(hpmap1[gd] > hpg.UNSEEN)
             hpmap_xor_union[gd[gd1]] = (hpmap_xor_union[gd[gd1]].astype(np.int64) ^
                                         hpmap1[gd[gd1]].astype(np.int64))
-            gd2, = np.where(hpmap2[gd] > hp.UNSEEN)
+            gd2, = np.where(hpmap2[gd] > hpg.UNSEEN)
             hpmap_xor_union[gd[gd2]] = (hpmap_xor_union[gd[gd2]].astype(np.int64) ^
                                         hpmap2[gd[gd2]].astype(np.int64))
 
@@ -651,17 +648,17 @@ class OperationsTestCase(unittest.TestCase):
             # xor 3
             xor_map_union = healsparse.xor_union([sparse_map1, sparse_map2, sparse_map3])
 
-            gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN) | (hpmap3 > hp.UNSEEN))
-            hpmap_xor_union = np.zeros_like(hpmap1) + hp.UNSEEN
+            gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN) | (hpmap3 > hpg.UNSEEN))
+            hpmap_xor_union = np.zeros_like(hpmap1) + hpg.UNSEEN
 
             hpmap_xor_union[gd] = 0.0
-            gd1, = np.where(hpmap1[gd] > hp.UNSEEN)
+            gd1, = np.where(hpmap1[gd] > hpg.UNSEEN)
             hpmap_xor_union[gd[gd1]] = (hpmap_xor_union[gd[gd1]].astype(np.int64) ^
                                         hpmap1[gd[gd1]].astype(np.int64))
-            gd2, = np.where(hpmap2[gd] > hp.UNSEEN)
+            gd2, = np.where(hpmap2[gd] > hpg.UNSEEN)
             hpmap_xor_union[gd[gd2]] = (hpmap_xor_union[gd[gd2]].astype(np.int64) ^
                                         hpmap2[gd[gd2]].astype(np.int64))
-            gd3, = np.where(hpmap3[gd] > hp.UNSEEN)
+            gd3, = np.where(hpmap3[gd] > hpg.UNSEEN)
             hpmap_xor_union[gd[gd3]] = (hpmap_xor_union[gd[gd3]].astype(np.int64) ^
                                         hpmap3[gd[gd3]].astype(np.int64))
 
@@ -671,8 +668,8 @@ class OperationsTestCase(unittest.TestCase):
 
             xor_map = sparse_map1 ^ 2
 
-            hpmap_xor2 = np.zeros_like(hpmap1) + hp.UNSEEN
-            gd, = np.where(hpmap1 > hp.UNSEEN)
+            hpmap_xor2 = np.zeros_like(hpmap1) + hpg.UNSEEN
+            gd, = np.where(hpmap1 > hpg.UNSEEN)
             hpmap_xor2[gd] = hpmap1[gd].astype(np.int64) ^ 2
             testing.assert_almost_equal(hpmap_xor2, xor_map.generate_healpix_map())
 
@@ -701,8 +698,8 @@ class OperationsTestCase(unittest.TestCase):
         # subtraction
         test_map = sparse_map1 - 2.0
 
-        hpmap_test = np.zeros_like(hpmap1) + hp.UNSEEN
-        gd, = np.where(hpmap1 > hp.UNSEEN)
+        hpmap_test = np.zeros_like(hpmap1) + hpg.UNSEEN
+        gd, = np.where(hpmap1 > hpg.UNSEEN)
         hpmap_test[gd] = hpmap1[gd] - 2.0
 
         testing.assert_almost_equal(hpmap_test, test_map.generate_healpix_map())
@@ -714,8 +711,8 @@ class OperationsTestCase(unittest.TestCase):
         # division
         test_map = sparse_map1 / 2.0
 
-        hpmap_test = np.zeros_like(hpmap1) + hp.UNSEEN
-        gd, = np.where(hpmap1 > hp.UNSEEN)
+        hpmap_test = np.zeros_like(hpmap1) + hpg.UNSEEN
+        gd, = np.where(hpmap1 > hpg.UNSEEN)
         hpmap_test[gd] = hpmap1[gd] / 2.0
 
         testing.assert_almost_equal(hpmap_test, test_map.generate_healpix_map())
@@ -727,8 +724,8 @@ class OperationsTestCase(unittest.TestCase):
         # power
         test_map = sparse_map1 ** 2.0
 
-        hpmap_test = np.zeros_like(hpmap1) + hp.UNSEEN
-        gd, = np.where(hpmap1 > hp.UNSEEN)
+        hpmap_test = np.zeros_like(hpmap1) + hpg.UNSEEN
+        gd, = np.where(hpmap1 > hpg.UNSEEN)
         hpmap_test[gd] = hpmap1[gd] ** 2.0
 
         testing.assert_almost_equal(hpmap_test, test_map.generate_healpix_map())
@@ -771,16 +768,16 @@ class OperationsTestCase(unittest.TestCase):
         # Maximum of 2
         max_map = healsparse.max_intersection([sparse_map1, sparse_map2])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-        hpmap_max = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+        hpmap_max = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_max[gd] = np.fmax(hpmap1[gd], hpmap2[gd])
 
         testing.assert_almost_equal(hpmap_max, max_map.generate_healpix_map())
 
         # Maximum of 3
         max_map = healsparse.max_intersection([sparse_map1, sparse_map2, sparse_map3])
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-        hpmap_max = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+        hpmap_max = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_max[gd] = np.fmax(hpmap1[gd], hpmap2[gd])
         hpmap_max[gd] = np.fmax(hpmap_max[gd], hpmap3[gd])
 
@@ -820,16 +817,16 @@ class OperationsTestCase(unittest.TestCase):
         # Minimum of 2
         min_map = healsparse.min_intersection([sparse_map1, sparse_map2])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-        hpmap_min = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+        hpmap_min = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_min[gd] = np.fmin(hpmap1[gd], hpmap2[gd])
 
         testing.assert_almost_equal(hpmap_min, min_map.generate_healpix_map())
 
         # Minimum of 3 intersection
         min_map = healsparse.min_intersection([sparse_map1, sparse_map2, sparse_map3])
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-        hpmap_min = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+        hpmap_min = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_min[gd] = np.fmin(hpmap1[gd], hpmap2[gd])
         hpmap_min[gd] = np.fmin(hpmap_min[gd], hpmap3[gd])
         testing.assert_almost_equal(hpmap_min, min_map.generate_healpix_map())
@@ -868,16 +865,16 @@ class OperationsTestCase(unittest.TestCase):
         # Maximum of 2 map union
         max_map = healsparse.max_union([sparse_map1, sparse_map2])
 
-        gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN))
-        hpmap_max = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN))
+        hpmap_max = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_max[gd] = np.fmax(hpmap1[gd], hpmap2[gd])
 
         testing.assert_almost_equal(hpmap_max, max_map.generate_healpix_map())
 
         # Maximum of 3 map union
         max_map = healsparse.max_union([sparse_map1, sparse_map2, sparse_map3])
-        gd, = np.where((hpmap1 > hp.UNSEEN) | (hpmap2 > hp.UNSEEN) | (hpmap3 > hp.UNSEEN))
-        hpmap_max = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) | (hpmap2 > hpg.UNSEEN) | (hpmap3 > hpg.UNSEEN))
+        hpmap_max = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_max[gd] = np.fmax(hpmap1[gd], hpmap2[gd])
         hpmap_max[gd] = np.fmax(hpmap_max[gd], hpmap3[gd])
 
@@ -917,21 +914,21 @@ class OperationsTestCase(unittest.TestCase):
         # Minimum of the union 2
         min_map = healsparse.min_union([sparse_map1, sparse_map2])
         # This is tricky because UNSEEN it's a float
-        hpmap1[hpmap1 == hp.UNSEEN] = -hp.UNSEEN
-        hpmap2[hpmap2 == hp.UNSEEN] = -hp.UNSEEN
-        gd, = np.where((hpmap1 < -hp.UNSEEN) | (hpmap2 < -hp.UNSEEN))
-        hpmap_min = np.zeros_like(hpmap1) + hp.UNSEEN
+        hpmap1[hpmap1 == hpg.UNSEEN] = -hpg.UNSEEN
+        hpmap2[hpmap2 == hpg.UNSEEN] = -hpg.UNSEEN
+        gd, = np.where((hpmap1 < -hpg.UNSEEN) | (hpmap2 < -hpg.UNSEEN))
+        hpmap_min = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_min[gd] = np.fmin(hpmap1[gd], hpmap2[gd])  # This would be the intersection
 
         testing.assert_almost_equal(hpmap_min, min_map.generate_healpix_map())
 
         # Maximum of 3
         min_map = healsparse.min_union([sparse_map1, sparse_map2, sparse_map3])
-        hpmap1[hpmap1 == hp.UNSEEN] = -hp.UNSEEN
-        hpmap2[hpmap2 == hp.UNSEEN] = -hp.UNSEEN
-        hpmap3[hpmap3 == hp.UNSEEN] = -hp.UNSEEN
-        gd, = np.where((hpmap1 < -hp.UNSEEN) | (hpmap2 < -hp.UNSEEN) | (hpmap3 < -hp.UNSEEN))
-        hpmap_min = np.zeros_like(hpmap1) + hp.UNSEEN
+        hpmap1[hpmap1 == hpg.UNSEEN] = -hpg.UNSEEN
+        hpmap2[hpmap2 == hpg.UNSEEN] = -hpg.UNSEEN
+        hpmap3[hpmap3 == hpg.UNSEEN] = -hpg.UNSEEN
+        gd, = np.where((hpmap1 < -hpg.UNSEEN) | (hpmap2 < -hpg.UNSEEN) | (hpmap3 < -hpg.UNSEEN))
+        hpmap_min = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_min[gd] = np.fmin(hpmap1[gd], hpmap2[gd])
         hpmap_min[gd] = np.fmin(hpmap_min[gd], hpmap3[gd])
 
@@ -971,8 +968,8 @@ class OperationsTestCase(unittest.TestCase):
         # Test an example ufunc (np.add) with 2 maps
 
         add_map = healsparse.ufunc_intersection([sparse_map1, sparse_map2], np.add)
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN))
-        hpmap_add = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN))
+        hpmap_add = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_add[gd] = np.add(hpmap1[gd], hpmap2[gd])
 
         testing.assert_almost_equal(hpmap_add, add_map.generate_healpix_map())
@@ -980,8 +977,8 @@ class OperationsTestCase(unittest.TestCase):
         # Test an example ufunc (np.add) with 3 maps
 
         add_map = healsparse.ufunc_intersection([sparse_map1, sparse_map2, sparse_map3], np.add)
-        gd, = np.where((hpmap1 > hp.UNSEEN) & (hpmap2 > hp.UNSEEN) & (hpmap3 > hp.UNSEEN))
-        hpmap_add = np.zeros_like(hpmap1) + hp.UNSEEN
+        gd, = np.where((hpmap1 > hpg.UNSEEN) & (hpmap2 > hpg.UNSEEN) & (hpmap3 > hpg.UNSEEN))
+        hpmap_add = np.zeros_like(hpmap1) + hpg.UNSEEN
         hpmap_add[gd] = np.add(hpmap1[gd], hpmap2[gd])
         hpmap_add[gd] = np.add(hpmap_add[gd], hpmap3[gd])
         testing.assert_almost_equal(hpmap_add, add_map.generate_healpix_map())
@@ -1020,21 +1017,21 @@ class OperationsTestCase(unittest.TestCase):
         # Test an example ufunc (np.add) with 2 maps
 
         add_map = healsparse.ufunc_union([sparse_map1, sparse_map2], np.add)
-        # This is tricky again because hp.UNSEEN is a float
-        mask = (hpmap1 == hp.UNSEEN) & (hpmap2 == hp.UNSEEN)
-        hpmap1[hpmap1 == hp.UNSEEN] = 0
-        hpmap2[hpmap2 == hp.UNSEEN] = 0
+        # This is tricky again because hpg.UNSEEN is a float
+        mask = (hpmap1 == hpg.UNSEEN) & (hpmap2 == hpg.UNSEEN)
+        hpmap1[hpmap1 == hpg.UNSEEN] = 0
+        hpmap2[hpmap2 == hpg.UNSEEN] = 0
         hpmap_add = np.add(hpmap1, hpmap2)
-        hpmap_add[mask] = hp.UNSEEN
+        hpmap_add[mask] = hpg.UNSEEN
         testing.assert_almost_equal(hpmap_add, add_map.generate_healpix_map())
 
         # Test an example ufunc (np.add) with 3 maps
         hpmap_add[mask] = 0
         add_map = healsparse.ufunc_union([sparse_map1, sparse_map2, sparse_map3], np.add)
-        mask2 = (mask) & (hpmap3 == hp.UNSEEN)
-        hpmap3[hpmap3 == hp.UNSEEN] = 0
+        mask2 = (mask) & (hpmap3 == hpg.UNSEEN)
+        hpmap3[hpmap3 == hpg.UNSEEN] = 0
         hpmap_add = np.add(hpmap_add, hpmap3)
-        hpmap_add[mask2] = hp.UNSEEN
+        hpmap_add[mask2] = hpg.UNSEEN
         testing.assert_almost_equal(hpmap_add, add_map.generate_healpix_map())
 
 
